package cn.iocoder.yudao.module.museums.controller.admin.museumsdocument;

import org.springframework.web.bind.annotation.*;
import javax.annotation.Resource;
import org.springframework.validation.annotation.Validated;
import org.springframework.security.access.prepost.PreAuthorize;
import io.swagger.v3.oas.annotations.tags.Tag;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.Operation;

import javax.validation.constraints.*;
import javax.validation.*;
import javax.servlet.http.*;
import java.util.*;
import java.io.IOException;

import cn.iocoder.yudao.framework.common.pojo.PageParam;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import cn.iocoder.yudao.framework.common.util.object.BeanUtils;
import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;

import cn.iocoder.yudao.framework.excel.core.util.ExcelUtils;

import cn.iocoder.yudao.framework.apilog.core.annotation.ApiAccessLog;
import static cn.iocoder.yudao.framework.apilog.core.enums.OperateTypeEnum.*;

import cn.iocoder.yudao.module.museums.controller.admin.museumsdocument.vo.*;
import cn.iocoder.yudao.module.museums.dal.dataobject.museumsdocument.MuseumsDocumentDO;
import cn.iocoder.yudao.module.museums.service.museumsdocument.MuseumsDocumentService;

@Tag(name = "管理后台 - 博物馆文件管理")
@RestController
@RequestMapping("/museums/document")
@Validated
public class MuseumsDocumentController {

    @Resource
    private MuseumsDocumentService documentService;

    @PostMapping("/create")
    @Operation(summary = "创建博物馆文件管理")
    @PreAuthorize("@ss.hasPermission('museums:document:create')")
    public CommonResult<Integer> createDocument(@Valid @RequestBody MuseumsDocumentSaveReqVO createReqVO) {
        return success(documentService.createDocument(createReqVO));
    }

    @PutMapping("/update")
    @Operation(summary = "更新博物馆文件管理")
    @PreAuthorize("@ss.hasPermission('museums:document:update')")
    public CommonResult<Boolean> updateDocument(@Valid @RequestBody MuseumsDocumentSaveReqVO updateReqVO) {
        documentService.updateDocument(updateReqVO);
        return success(true);
    }

    @DeleteMapping("/delete")
    @Operation(summary = "删除博物馆文件管理")
    @Parameter(name = "id", description = "编号", required = true)
    @PreAuthorize("@ss.hasPermission('museums:document:delete')")
    public CommonResult<Boolean> deleteDocument(@RequestParam("id") Integer id) {
        documentService.deleteDocument(id);
        return success(true);
    }

    @GetMapping("/get")
    @Operation(summary = "获得博物馆文件管理")
    @Parameter(name = "id", description = "编号", required = true, example = "1024")
    @PreAuthorize("@ss.hasPermission('museums:document:query')")
    public CommonResult<MuseumsDocumentRespVO> getDocument(@RequestParam("id") Integer id) {
        MuseumsDocumentDO document = documentService.getDocument(id);
        return success(BeanUtils.toBean(document, MuseumsDocumentRespVO.class));
    }

    @GetMapping("/page")
    @Operation(summary = "获得博物馆文件管理分页")
    @PreAuthorize("@ss.hasPermission('museums:document:query')")
    public CommonResult<PageResult<MuseumsDocumentRespVO>> getDocumentPage(@Valid MuseumsDocumentPageReqVO pageReqVO) {
        PageResult<MuseumsDocumentDO> pageResult = documentService.getDocumentPage(pageReqVO);
        return success(BeanUtils.toBean(pageResult, MuseumsDocumentRespVO.class));
    }

    @GetMapping("/export-excel")
    @Operation(summary = "导出博物馆文件管理 Excel")
    @PreAuthorize("@ss.hasPermission('museums:document:export')")
    @ApiAccessLog(operateType = EXPORT)
    public void exportDocumentExcel(@Valid MuseumsDocumentPageReqVO pageReqVO,
              HttpServletResponse response) throws IOException {
        pageReqVO.setPageSize(PageParam.PAGE_SIZE_NONE);
        List<MuseumsDocumentDO> list = documentService.getDocumentPage(pageReqVO).getList();
        // 导出 Excel
        ExcelUtils.write(response, "博物馆文件管理.xls", "数据", MuseumsDocumentRespVO.class,
                        BeanUtils.toBean(list, MuseumsDocumentRespVO.class));
    }

}