package cn.iocoder.yudao.module.museums.controller.admin.photogroup;

import org.springframework.web.bind.annotation.*;
import javax.annotation.Resource;
import org.springframework.validation.annotation.Validated;
import org.springframework.security.access.prepost.PreAuthorize;
import io.swagger.v3.oas.annotations.tags.Tag;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.Operation;

import javax.validation.constraints.*;
import javax.validation.*;
import javax.servlet.http.*;
import java.util.*;
import java.io.IOException;

import cn.iocoder.yudao.framework.common.pojo.PageParam;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import cn.iocoder.yudao.framework.common.util.object.BeanUtils;
import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;

import cn.iocoder.yudao.framework.excel.core.util.ExcelUtils;

import cn.iocoder.yudao.framework.apilog.core.annotation.ApiAccessLog;
import static cn.iocoder.yudao.framework.apilog.core.enums.OperateTypeEnum.*;

import cn.iocoder.yudao.module.museums.controller.admin.photogroup.vo.*;
import cn.iocoder.yudao.module.museums.dal.dataobject.photogroup.PhotoGroupDO;
import cn.iocoder.yudao.module.museums.service.photogroup.PhotoGroupService;

@Tag(name = "管理后台 - 博物馆照片组")
@RestController
@RequestMapping("/museums/photo-group")
@Validated
public class PhotoGroupController {

    @Resource
    private PhotoGroupService photoGroupService;

    @PostMapping("/create")
    @Operation(summary = "创建博物馆照片组")
    @PreAuthorize("@ss.hasPermission('museums:photo-group:create')")
    public CommonResult<Integer> createPhotoGroup(@Valid @RequestBody PhotoGroupSaveReqVO createReqVO) {
        return success(photoGroupService.createPhotoGroup(createReqVO));
    }

    @PutMapping("/update")
    @Operation(summary = "更新博物馆照片组")
    @PreAuthorize("@ss.hasPermission('museums:photo-group:update')")
    public CommonResult<Boolean> updatePhotoGroup(@Valid @RequestBody PhotoGroupSaveReqVO updateReqVO) {
        photoGroupService.updatePhotoGroup(updateReqVO);
        return success(true);
    }

    @DeleteMapping("/delete")
    @Operation(summary = "删除博物馆照片组")
    @Parameter(name = "id", description = "编号", required = true)
    @PreAuthorize("@ss.hasPermission('museums:photo-group:delete')")
    public CommonResult<Boolean> deletePhotoGroup(@RequestParam("id") Integer id) {
        photoGroupService.deletePhotoGroup(id);
        return success(true);
    }

    @GetMapping("/get")
    @Operation(summary = "获得博物馆照片组")
    @Parameter(name = "id", description = "编号", required = true, example = "1024")
    @PreAuthorize("@ss.hasPermission('museums:photo-group:query')")
    public CommonResult<PhotoGroupRespVO> getPhotoGroup(@RequestParam("id") Integer id) {
        PhotoGroupDO photoGroup = photoGroupService.getPhotoGroup(id);
        return success(BeanUtils.toBean(photoGroup, PhotoGroupRespVO.class));
    }

    @GetMapping("/page")
    @Operation(summary = "获得博物馆照片组分页")
    @PreAuthorize("@ss.hasPermission('museums:photo-group:query')")
    public CommonResult<PageResult<PhotoGroupRespVO>> getPhotoGroupPage(@Valid PhotoGroupPageReqVO pageReqVO) {
        PageResult<PhotoGroupDO> pageResult = photoGroupService.getPhotoGroupPage(pageReqVO);
        return success(BeanUtils.toBean(pageResult, PhotoGroupRespVO.class));
    }

    @GetMapping("/export-excel")
    @Operation(summary = "导出博物馆照片组 Excel")
    @PreAuthorize("@ss.hasPermission('museums:photo-group:export')")
    @ApiAccessLog(operateType = EXPORT)
    public void exportPhotoGroupExcel(@Valid PhotoGroupPageReqVO pageReqVO,
              HttpServletResponse response) throws IOException {
        pageReqVO.setPageSize(PageParam.PAGE_SIZE_NONE);
        List<PhotoGroupDO> list = photoGroupService.getPhotoGroupPage(pageReqVO).getList();
        // 导出 Excel
        ExcelUtils.write(response, "博物馆照片组.xls", "数据", PhotoGroupRespVO.class,
                        BeanUtils.toBean(list, PhotoGroupRespVO.class));
    }

}