package cn.iocoder.yudao.module.museums.controller.admin.specimeninfo;

import org.springframework.web.bind.annotation.*;
import javax.annotation.Resource;
import org.springframework.validation.annotation.Validated;
import org.springframework.security.access.prepost.PreAuthorize;
import io.swagger.v3.oas.annotations.tags.Tag;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.Operation;

import javax.validation.constraints.*;
import javax.validation.*;
import javax.servlet.http.*;
import java.util.*;
import java.io.IOException;

import cn.iocoder.yudao.framework.common.pojo.PageParam;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import cn.iocoder.yudao.framework.common.util.object.BeanUtils;
import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;

import cn.iocoder.yudao.framework.excel.core.util.ExcelUtils;

import cn.iocoder.yudao.framework.apilog.core.annotation.ApiAccessLog;
import static cn.iocoder.yudao.framework.apilog.core.enums.OperateTypeEnum.*;

import cn.iocoder.yudao.module.museums.controller.admin.specimeninfo.vo.*;
import cn.iocoder.yudao.module.museums.dal.dataobject.specimeninfo.SpecimenInfoDO;
import cn.iocoder.yudao.module.museums.service.specimeninfo.SpecimenInfoService;

@Tag(name = "管理后台 - 标本管理")
@RestController
@RequestMapping("/museums/specimen-info")
@Validated
public class SpecimenInfoController {

    @Resource
    private SpecimenInfoService specimenInfoService;

    @PostMapping("/create")
    @Operation(summary = "创建标本管理")
    @PreAuthorize("@ss.hasPermission('museums:specimen-info:create')")
    public CommonResult<Integer> createSpecimenInfo(@Valid @RequestBody SpecimenInfoSaveReqVO createReqVO) {
        return success(specimenInfoService.createSpecimenInfo(createReqVO));
    }

    @PutMapping("/update")
    @Operation(summary = "更新标本管理")
    @PreAuthorize("@ss.hasPermission('museums:specimen-info:update')")
    public CommonResult<Boolean> updateSpecimenInfo(@Valid @RequestBody SpecimenInfoSaveReqVO updateReqVO) {
        specimenInfoService.updateSpecimenInfo(updateReqVO);
        return success(true);
    }

    @DeleteMapping("/delete")
    @Operation(summary = "删除标本管理")
    @Parameter(name = "id", description = "编号", required = true)
    @PreAuthorize("@ss.hasPermission('museums:specimen-info:delete')")
    public CommonResult<Boolean> deleteSpecimenInfo(@RequestParam("id") Integer id) {
        specimenInfoService.deleteSpecimenInfo(id);
        return success(true);
    }

    @GetMapping("/get")
    @Operation(summary = "获得标本管理")
    @Parameter(name = "id", description = "编号", required = true, example = "1024")
    @PreAuthorize("@ss.hasPermission('museums:specimen-info:query')")
    public CommonResult<SpecimenInfoRespVO> getSpecimenInfo(@RequestParam("id") Integer id) {
        SpecimenInfoDO specimenInfo = specimenInfoService.getSpecimenInfo(id);
        return success(BeanUtils.toBean(specimenInfo, SpecimenInfoRespVO.class));
    }

    @GetMapping("/page")
    @Operation(summary = "获得标本管理分页")
    @PreAuthorize("@ss.hasPermission('museums:specimen-info:query')")
    public CommonResult<PageResult<SpecimenInfoRespVO>> getSpecimenInfoPage(@Valid SpecimenInfoPageReqVO pageReqVO) {
        PageResult<SpecimenInfoDO> pageResult = specimenInfoService.getSpecimenInfoPage(pageReqVO);
        return success(BeanUtils.toBean(pageResult, SpecimenInfoRespVO.class));
    }

    @GetMapping("/export-excel")
    @Operation(summary = "导出标本管理 Excel")
    @PreAuthorize("@ss.hasPermission('museums:specimen-info:export')")
    @ApiAccessLog(operateType = EXPORT)
    public void exportSpecimenInfoExcel(@Valid SpecimenInfoPageReqVO pageReqVO,
              HttpServletResponse response) throws IOException {
        pageReqVO.setPageSize(PageParam.PAGE_SIZE_NONE);
        List<SpecimenInfoDO> list = specimenInfoService.getSpecimenInfoPage(pageReqVO).getList();
        // 导出 Excel
        ExcelUtils.write(response, "标本管理.xls", "数据", SpecimenInfoRespVO.class,
                        BeanUtils.toBean(list, SpecimenInfoRespVO.class));
    }

}