package cn.iocoder.yudao.module.museums.controller.admin.specimenoutbound;

import org.springframework.web.bind.annotation.*;
import javax.annotation.Resource;
import org.springframework.validation.annotation.Validated;
import org.springframework.security.access.prepost.PreAuthorize;
import io.swagger.v3.oas.annotations.tags.Tag;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.Operation;

import javax.validation.constraints.*;
import javax.validation.*;
import javax.servlet.http.*;
import java.util.*;
import java.io.IOException;

import cn.iocoder.yudao.framework.common.pojo.PageParam;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import cn.iocoder.yudao.framework.common.util.object.BeanUtils;
import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;

import cn.iocoder.yudao.framework.excel.core.util.ExcelUtils;

import cn.iocoder.yudao.framework.apilog.core.annotation.ApiAccessLog;
import static cn.iocoder.yudao.framework.apilog.core.enums.OperateTypeEnum.*;

import cn.iocoder.yudao.module.museums.controller.admin.specimenoutbound.vo.*;
import cn.iocoder.yudao.module.museums.dal.dataobject.specimenoutbound.SpecimenOutboundDO;
import cn.iocoder.yudao.module.museums.service.specimenoutbound.SpecimenOutboundService;

@Tag(name = "管理后台 - 标本出库回库信息")
@RestController
@RequestMapping("/museums/specimen-outbound")
@Validated
public class SpecimenOutboundController {

    @Resource
    private SpecimenOutboundService specimenOutboundService;

    @PostMapping("/create")
    @Operation(summary = "创建标本出库回库信息")
    @PreAuthorize("@ss.hasPermission('museums:specimen-outbound:create')")
    public CommonResult<Integer> createSpecimenOutbound(@Valid @RequestBody SpecimenOutboundSaveReqVO createReqVO) {
        return success(specimenOutboundService.createSpecimenOutbound(createReqVO));
    }

    @PutMapping("/update")
    @Operation(summary = "更新标本出库回库信息")
    @PreAuthorize("@ss.hasPermission('museums:specimen-outbound:update')")
    public CommonResult<Boolean> updateSpecimenOutbound(@Valid @RequestBody SpecimenOutboundSaveReqVO updateReqVO) {
        specimenOutboundService.updateSpecimenOutbound(updateReqVO);
        return success(true);
    }

    @DeleteMapping("/delete")
    @Operation(summary = "删除标本出库回库信息")
    @Parameter(name = "id", description = "编号", required = true)
    @PreAuthorize("@ss.hasPermission('museums:specimen-outbound:delete')")
    public CommonResult<Boolean> deleteSpecimenOutbound(@RequestParam("id") Integer id) {
        specimenOutboundService.deleteSpecimenOutbound(id);
        return success(true);
    }

    @GetMapping("/get")
    @Operation(summary = "获得标本出库回库信息")
    @Parameter(name = "id", description = "编号", required = true, example = "1024")
    @PreAuthorize("@ss.hasPermission('museums:specimen-outbound:query')")
    public CommonResult<SpecimenOutboundRespVO> getSpecimenOutbound(@RequestParam("id") Integer id) {
        SpecimenOutboundDO specimenOutbound = specimenOutboundService.getSpecimenOutbound(id);
        return success(BeanUtils.toBean(specimenOutbound, SpecimenOutboundRespVO.class));
    }

    @GetMapping("/page")
    @Operation(summary = "获得标本出库回库信息分页")
    @PreAuthorize("@ss.hasPermission('museums:specimen-outbound:query')")
    public CommonResult<PageResult<SpecimenOutboundRespVO>> getSpecimenOutboundPage(@Valid SpecimenOutboundPageReqVO pageReqVO) {
        PageResult<SpecimenOutboundDO> pageResult = specimenOutboundService.getSpecimenOutboundPage(pageReqVO);
        return success(BeanUtils.toBean(pageResult, SpecimenOutboundRespVO.class));
    }

    @GetMapping("/export-excel")
    @Operation(summary = "导出标本出库回库信息 Excel")
    @PreAuthorize("@ss.hasPermission('museums:specimen-outbound:export')")
    @ApiAccessLog(operateType = EXPORT)
    public void exportSpecimenOutboundExcel(@Valid SpecimenOutboundPageReqVO pageReqVO,
              HttpServletResponse response) throws IOException {
        pageReqVO.setPageSize(PageParam.PAGE_SIZE_NONE);
        List<SpecimenOutboundDO> list = specimenOutboundService.getSpecimenOutboundPage(pageReqVO).getList();
        // 导出 Excel
        ExcelUtils.write(response, "标本出库回库信息.xls", "数据", SpecimenOutboundRespVO.class,
                        BeanUtils.toBean(list, SpecimenOutboundRespVO.class));
    }

}