package cn.iocoder.yudao.module.museums.service.specimenoutbound;

import org.springframework.stereotype.Service;
import javax.annotation.Resource;
import org.springframework.validation.annotation.Validated;
import org.springframework.transaction.annotation.Transactional;

import java.util.*;
import cn.iocoder.yudao.module.museums.controller.admin.specimenoutbound.vo.*;
import cn.iocoder.yudao.module.museums.dal.dataobject.specimenoutbound.SpecimenOutboundDO;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.common.pojo.PageParam;
import cn.iocoder.yudao.framework.common.util.object.BeanUtils;

import cn.iocoder.yudao.module.museums.dal.mysql.specimenoutbound.SpecimenOutboundMapper;

import static cn.iocoder.yudao.framework.common.exception.util.ServiceExceptionUtil.exception;
import static cn.iocoder.yudao.module.museums.enums.ErrorCodeConstants.*;

/**
 * 标本出库回库信息 Service 实现类
 *
 * @author qpw
 */
@Service
@Validated
public class SpecimenOutboundServiceImpl implements SpecimenOutboundService {

    @Resource
    private SpecimenOutboundMapper specimenOutboundMapper;

    @Override
    public Integer createSpecimenOutbound(SpecimenOutboundSaveReqVO createReqVO) {
        // 插入
        SpecimenOutboundDO specimenOutbound = BeanUtils.toBean(createReqVO, SpecimenOutboundDO.class);
        specimenOutboundMapper.insert(specimenOutbound);
        // 返回
        return specimenOutbound.getId();
    }

    @Override
    public void updateSpecimenOutbound(SpecimenOutboundSaveReqVO updateReqVO) {
        // 校验存在
        validateSpecimenOutboundExists(updateReqVO.getId());
        // 更新
        SpecimenOutboundDO updateObj = BeanUtils.toBean(updateReqVO, SpecimenOutboundDO.class);
        specimenOutboundMapper.updateById(updateObj);
    }

    @Override
    public void deleteSpecimenOutbound(Integer id) {
        // 校验存在
        validateSpecimenOutboundExists(id);
        // 删除
        specimenOutboundMapper.deleteById(id);
    }

    private void validateSpecimenOutboundExists(Integer id) {
        if (specimenOutboundMapper.selectById(id) == null) {
            throw exception(SPECIMEN_OUTBOUND_NOT_EXISTS);
        }
    }

    @Override
    public SpecimenOutboundDO getSpecimenOutbound(Integer id) {
        return specimenOutboundMapper.selectById(id);
    }

    @Override
    public PageResult<SpecimenOutboundDO> getSpecimenOutboundPage(SpecimenOutboundPageReqVO pageReqVO) {
        return specimenOutboundMapper.selectPage(pageReqVO);
    }

}