package cn.iocoder.yudao.module.museums.service.museumsdocument;

import org.junit.jupiter.api.Disabled;
import org.junit.jupiter.api.Test;
import org.springframework.boot.test.mock.mockito.MockBean;

import javax.annotation.Resource;

import cn.iocoder.yudao.framework.test.core.ut.BaseDbUnitTest;

import cn.iocoder.yudao.module.museums.controller.admin.museumsdocument.vo.*;
import cn.iocoder.yudao.module.museums.dal.dataobject.museumsdocument.MuseumsDocumentDO;
import cn.iocoder.yudao.module.museums.dal.mysql.museumsdocument.MuseumsDocumentMapper;
import cn.iocoder.yudao.framework.common.pojo.PageResult;

import javax.annotation.Resource;
import org.springframework.context.annotation.Import;
import java.util.*;
import java.time.LocalDateTime;

import static cn.hutool.core.util.RandomUtil.*;
import static cn.iocoder.yudao.module.museums.enums.ErrorCodeConstants.*;
import static cn.iocoder.yudao.framework.test.core.util.AssertUtils.*;
import static cn.iocoder.yudao.framework.test.core.util.RandomUtils.*;
import static cn.iocoder.yudao.framework.common.util.date.LocalDateTimeUtils.*;
import static cn.iocoder.yudao.framework.common.util.object.ObjectUtils.*;
import static cn.iocoder.yudao.framework.common.util.date.DateUtils.*;
import static org.junit.jupiter.api.Assertions.*;
import static org.mockito.Mockito.*;

/**
 * {@link MuseumsDocumentServiceImpl} 的单元测试类
 *
 * @author 芋道源码
 */
@Import(MuseumsDocumentServiceImpl.class)
public class MuseumsDocumentServiceImplTest extends BaseDbUnitTest {

    @Resource
    private MuseumsDocumentServiceImpl documentService;

    @Resource
    private MuseumsDocumentMapper documentMapper;

    @Test
    public void testCreateDocument_success() {
        // 准备参数
        MuseumsDocumentSaveReqVO createReqVO = randomPojo(MuseumsDocumentSaveReqVO.class).setId(null);

        // 调用
        Integer documentId = documentService.createDocument(createReqVO);
        // 断言
        assertNotNull(documentId);
        // 校验记录的属性是否正确
        MuseumsDocumentDO document = documentMapper.selectById(documentId);
        assertPojoEquals(createReqVO, document, "id");
    }

    @Test
    public void testUpdateDocument_success() {
        // mock 数据
        MuseumsDocumentDO dbDocument = randomPojo(MuseumsDocumentDO.class);
        documentMapper.insert(dbDocument);// @Sql: 先插入出一条存在的数据
        // 准备参数
        MuseumsDocumentSaveReqVO updateReqVO = randomPojo(MuseumsDocumentSaveReqVO.class, o -> {
            o.setId(dbDocument.getId()); // 设置更新的 ID
        });

        // 调用
        documentService.updateDocument(updateReqVO);
        // 校验是否更新正确
        MuseumsDocumentDO document = documentMapper.selectById(updateReqVO.getId()); // 获取最新的
        assertPojoEquals(updateReqVO, document);
    }

    @Test
    public void testUpdateDocument_notExists() {
        // 准备参数
        MuseumsDocumentSaveReqVO updateReqVO = randomPojo(MuseumsDocumentSaveReqVO.class);

        // 调用, 并断言异常
        assertServiceException(() -> documentService.updateDocument(updateReqVO), DOCUMENT_NOT_EXISTS);
    }

    @Test
    public void testDeleteDocument_success() {
        // mock 数据
        MuseumsDocumentDO dbDocument = randomPojo(MuseumsDocumentDO.class);
        documentMapper.insert(dbDocument);// @Sql: 先插入出一条存在的数据
        // 准备参数
        Integer id = dbDocument.getId();

        // 调用
        documentService.deleteDocument(id);
       // 校验数据不存在了
       assertNull(documentMapper.selectById(id));
    }

    @Test
    public void testDeleteDocument_notExists() {
        // 准备参数
        Integer id = randomIntegerId();

        // 调用, 并断言异常
        assertServiceException(() -> documentService.deleteDocument(id), DOCUMENT_NOT_EXISTS);
    }

    @Test
    @Disabled  // TODO 请修改 null 为需要的值，然后删除 @Disabled 注解
    public void testGetDocumentPage() {
       // mock 数据
       MuseumsDocumentDO dbDocument = randomPojo(MuseumsDocumentDO.class, o -> { // 等会查询到
           o.setFileName(null);
           o.setConfigId(null);
           o.setPath(null);
           o.setUrl(null);
           o.setFileSize(null);
           o.setFileType(null);
           o.setUploadDate(null);
           o.setUploadedBy(null);
           o.setCreateTime(null);
       });
       documentMapper.insert(dbDocument);
       // 测试 fileName 不匹配
       documentMapper.insert(cloneIgnoreId(dbDocument, o -> o.setFileName(null)));
       // 测试 configId 不匹配
       documentMapper.insert(cloneIgnoreId(dbDocument, o -> o.setConfigId(null)));
       // 测试 path 不匹配
       documentMapper.insert(cloneIgnoreId(dbDocument, o -> o.setPath(null)));
       // 测试 url 不匹配
       documentMapper.insert(cloneIgnoreId(dbDocument, o -> o.setUrl(null)));
       // 测试 fileSize 不匹配
       documentMapper.insert(cloneIgnoreId(dbDocument, o -> o.setFileSize(null)));
       // 测试 fileType 不匹配
       documentMapper.insert(cloneIgnoreId(dbDocument, o -> o.setFileType(null)));
       // 测试 uploadDate 不匹配
       documentMapper.insert(cloneIgnoreId(dbDocument, o -> o.setUploadDate(null)));
       // 测试 uploadedBy 不匹配
       documentMapper.insert(cloneIgnoreId(dbDocument, o -> o.setUploadedBy(null)));
       // 测试 createTime 不匹配
       documentMapper.insert(cloneIgnoreId(dbDocument, o -> o.setCreateTime(null)));
       // 准备参数
       MuseumsDocumentPageReqVO reqVO = new MuseumsDocumentPageReqVO();
       reqVO.setFileName(null);
       reqVO.setConfigId(null);
       reqVO.setPath(null);
       reqVO.setUrl(null);
       reqVO.setFileSize(null);
       reqVO.setFileType(null);
       reqVO.setUploadDate(buildBetweenTime(2023, 2, 1, 2023, 2, 28));
       reqVO.setUploadedBy(null);
       reqVO.setCreateTime(buildBetweenTime(2023, 2, 1, 2023, 2, 28));

       // 调用
       PageResult<MuseumsDocumentDO> pageResult = documentService.getDocumentPage(reqVO);
       // 断言
       assertEquals(1, pageResult.getTotal());
       assertEquals(1, pageResult.getList().size());
       assertPojoEquals(dbDocument, pageResult.getList().get(0));
    }

}